@@ -1,44 +1,38 @@
 /*
-  Copyright (c) 2013-2019 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef CHECKEDCOLLECTIONWIDGET_H
 #define CHECKEDCOLLECTIONWIDGET_H
 
-#include <QWidget>
 #include "pimcommonakonadi_export.h"
+#include <QWidget>
 
 class QItemSelectionModel;
 class QTreeView;
 class KCheckableProxyModel;
 
-namespace Akonadi {
+namespace Akonadi
+{
 class EntityTreeModel;
 class Collection;
 }
 
-namespace PimCommon {
+namespace PimCommon
+{
 class CheckedCollectionWidgetPrivate;
+/**
+ * @brief The CheckedCollectionWidget class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class PIMCOMMONAKONADI_EXPORT CheckedCollectionWidget : public QWidget
 {
     Q_OBJECT
 public:
     explicit CheckedCollectionWidget(const QString &mimetype, QWidget *parent = nullptr);
-    ~CheckedCollectionWidget();
+    ~CheckedCollectionWidget() override;
 
     Q_REQUIRED_RESULT Akonadi::EntityTreeModel *entityTreeModel() const;
 
